Numpy
=====


Video Barcode
-------------

A video barcode shows the change in colour and tone over time. Time is represented on the horizontal axis, while the vertical remains the vertical direction in the image.

See http://moviebarcode.tumblr.com/ for examples from Hollywood movies, and here is an example from a sunset timelapse:

.. image:: ../_static/examples/numpy/barcode.jpg

The code that created this:

.. literalinclude:: ../../examples/numpy/barcode.py


Generating Video
----------------

.. literalinclude:: ../../examples/numpy/generate_video.py


